Burdock Lab
===========

## ⚠ Warning! ⚠

Burdock Lab is under development, and should be considered pre-alpha quality software. 

Nothing works yet, and everything is subject to change. Caveat emptor!

## What is this?

[Burdock](https://github.com/DylanLukes/burdock) is a [Daikon](http://plse.cs.washington.edu/daikon/) frontend for Python dataframes (from Pandas) and CSV/TSV files.

This is a JupyterLab integration to support displaying invariants for active notebooks or consoles. It doesn't work yet.